diff --git a/dlls/ole32/tests/clipboard.c b/dlls/ole32/tests/clipboard.c
index e58ac02..3f61487 100644
--- a/dlls/ole32/tests/clipboard.c
+++ b/dlls/ole32/tests/clipboard.c
@@ -546,6 +546,7 @@ static void test_enum_fmtetc(IDataObject *src)
     IEnumFORMATETC *enum_fmt, *src_enum;
     FORMATETC fmt, src_fmt;
     DWORD count = 0;
+    IMalloc *allocator;
 
     hr = OleGetClipboard(&data);
     ok(hr == S_OK, "OleGetClipboard failed with error 0x%08x\n", hr);
@@ -575,6 +576,39 @@ static void test_enum_fmtetc(IDataObject *src)
         if(fmt.ptd)
         {
             ok(src_fmt.ptd != NULL, "%d: expected non-NULL\n", count);
+            hr = CoGetMalloc(1, &allocator);
+            ok(SUCCEEDED(hr), "Unable to obtain task mem allocator 0x%x\n", hr);
+            ok(fmt.ptd->tdSize <= IMalloc_GetSize(allocator, fmt.ptd),
+               "ptd size is %d but allocation size is only %d\n",
+               fmt.ptd->tdSize, IMalloc_GetSize(allocator, fmt.ptd));
+            IMalloc_Release(allocator);
+            ok(FIELD_OFFSET(DVTARGETDEVICE, tdData) <= fmt.ptd->tdSize,
+               "ptd size is %d but should be at least %d\n",
+               fmt.ptd->tdSize, FIELD_OFFSET(DVTARGETDEVICE, tdData));
+            ok(fmt.ptd->tdDriverNameOffset == 0 ||
+               (FIELD_OFFSET(DVTARGETDEVICE, tdData) <= fmt.ptd->tdDriverNameOffset && fmt.ptd->tdDriverNameOffset < fmt.ptd->tdSize),
+               "Invalid tdDriverNameOffset %d\n", fmt.ptd->tdDriverNameOffset);
+            if (fmt.ptd->tdDriverNameOffset != 0)
+              ok(lstrcmpW((WCHAR *)((char *) fmt.ptd + fmt.ptd->tdDriverNameOffset),
+                          (WCHAR *)((char *) src_fmt.ptd + src_fmt.ptd->tdDriverNameOffset)) == 0,
+                 "DriverNames don't match\n");
+            ok(fmt.ptd->tdDeviceNameOffset == 0 ||
+               (FIELD_OFFSET(DVTARGETDEVICE, tdData) <= fmt.ptd->tdDeviceNameOffset && fmt.ptd->tdDeviceNameOffset < fmt.ptd->tdSize),
+               "Invalid tdDeviceNameOffset %d\n", fmt.ptd->tdDeviceNameOffset);
+            if (fmt.ptd->tdDeviceNameOffset != 0)
+              ok(lstrcmpW((WCHAR *)((char *) fmt.ptd + fmt.ptd->tdDeviceNameOffset),
+                          (WCHAR *)((char *) src_fmt.ptd + src_fmt.ptd->tdDeviceNameOffset)) == 0,
+                 "DeviceNames don't match\n");
+            ok(fmt.ptd->tdPortNameOffset == 0 ||
+               (FIELD_OFFSET(DVTARGETDEVICE, tdData) <= fmt.ptd->tdPortNameOffset && fmt.ptd->tdPortNameOffset < fmt.ptd->tdSize),
+               "Invalid tdPortNameOffset %d\n", fmt.ptd->tdPortNameOffset);
+            if (fmt.ptd->tdPortNameOffset != 0)
+              ok(lstrcmpW((WCHAR *)((char *) fmt.ptd + fmt.ptd->tdPortNameOffset),
+                          (WCHAR *)((char *) src_fmt.ptd + src_fmt.ptd->tdPortNameOffset)) == 0,
+                 "PortNames don't match\n");
+            ok(fmt.ptd->tdExtDevmodeOffset == 0 ||
+               (FIELD_OFFSET(DVTARGETDEVICE, tdData) <= fmt.ptd->tdExtDevmodeOffset && fmt.ptd->tdExtDevmodeOffset < fmt.ptd->tdSize),
+               "Invalid tdExtDevmodeOffset %d\n", fmt.ptd->tdExtDevmodeOffset);
             CoTaskMemFree(fmt.ptd);
             CoTaskMemFree(src_fmt.ptd);
         }
